update

package
v0.6.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 30, 2026 License: MIT Imports: 12 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var PrismHooks = []struct {
	Event   string
	Command string
}{
	{"UserPromptSubmit", "$HOME/.claude/prism hook busy"},
	{"Stop", "$HOME/.claude/prism hook idle"},
	{"SessionStart", "$HOME/.claude/prism hook session-start"},
	{"SessionEnd", "$HOME/.claude/prism hook session-end"},
	{"PreCompact", "$HOME/.claude/prism hook pre-compact"},
	{"Setup", "$HOME/.claude/prism hook setup"},
}

PrismHooks defines all hooks that Prism needs wired up

Functions

func Download

func Download(ctx context.Context) error

Download fetches and installs the latest binary

func MigrateSettings added in v0.5.0

func MigrateSettings() (int, error)

MigrateSettings ensures all Prism hooks are wired up in settings.json Returns the number of hooks added (0 if already up to date)

Types

type Info

type Info struct {
	CurrentVersion  string
	LatestVersion   string
	UpdateAvailable bool
}

Info contains update check results

func Check

func Check(ctx context.Context) (*Info, error)

Check fetches the latest version and compares with current

Jump to