Documentation
¶
Index ¶
Constants ¶
const ( GitTTL = 2 * time.Second ProcessTTL = 2 * time.Second ConfigTTL = 10 * time.Second WorktreeTTL = 5 * time.Minute // Worktree status rarely changes )
Common TTL constants
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Cache ¶
type Cache struct {
// contains filtered or unexported fields
}
Cache provides thread-safe in-memory caching with TTL
func (*Cache) DeleteByPrefix ¶
DeleteByPrefix removes all keys with the given prefix
func (*Cache) Get ¶
Get retrieves a value from the cache Returns the value and true if found and not expired, empty string and false otherwise
Click to show internal directories.
Click to hide internal directories.