package
Version:
v0.3.0
Opens a new window with list of versions in this module.
Published: Jan 13, 2026
License: MIT
Opens a new window with license information.
Imports: 12
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Download fetches and installs the latest binary
type Info struct {
CurrentVersion string
LatestVersion string
UpdateAvailable bool
}
Info contains update check results
Check fetches the latest version and compares with current
Source Files
¶
Click to show internal directories.
Click to hide internal directories.